API docs for “spamfighter.core.null_partner.NullPartnerAuthorizer”

# Class s.c.n.NullPartnerAuthorizer(object):

Part of spamfighter.core.null_partner View Source View In Hierarchy

Провайдер авторизации партнеров без логина/пароля (на доверии).

В этой ситуации доступ к СпамоБорцу ограничен с помощью других средств (HTTP-proxy, firewall).

Instance Variables | partner | единственный партнер, который обеспечивает весь доступ (type: `NullPartner` )

Method | __init__ | Конструктор.
Method | authorize | Выполнить авторизацию партнера.

def __init__(self): (source)
Конструктор.

def authorize(self, partner_info): (source)
Выполнить авторизацию партнера.

Parameters | partner_info | информация о партнере
Returns | Deferred, партнер (`IPartner`) (type: `twisted.internet.defer.Deferred` )